@@ -1,17 +1,24 @@
 """Command-line implementation of flake8."""
+from __future__ import annotations
+
+import sys
+from typing import Sequence
+
 from flake8.main import application
 
 
-def main(argv=None):
-    # type: (Union[NoneType, List[str]]) -> NoneType
+def main(argv: Sequence[str] | None = None) -> int:
     """Execute the main bit of the application.
 
     This handles the creation of an instance of :class:`Application`, runs it,
     and then exits the application.
 
-    :param list argv:
+    :param argv:
         The arguments to be passed to the application for parsing.
     """
+    if argv is None:
+        argv = sys.argv[1:]
+
     app = application.Application()
     app.run(argv)
-    app.exit()
+    return app.exit_code()
