@@ -1,13 +1,10 @@
 """Statistic collection logic for Flake8."""
-import collections
-from typing import Dict
-from typing import Generator
-from typing import List
-from typing import Optional
-from typing import TYPE_CHECKING
+from __future__ import annotations
 
-if TYPE_CHECKING:
-    from flake8.style_guide import Violation
+from typing import Generator
+from typing import NamedTuple
+
+from flake8.violation import Violation
 
 
 class Statistics:
@@ -15,26 +12,22 @@ class Statistics:
 
     def __init__(self) -> None:
         """Initialize the underlying dictionary for our statistics."""
-        self._store: Dict[Key, "Statistic"] = {}
+        self._store: dict[Key, Statistic] = {}
 
-    def error_codes(self) -> List[str]:
+    def error_codes(self) -> list[str]:
         """Return all unique error codes stored.
 
         :returns:
             Sorted list of error codes.
-        :rtype:
-            list(str)
         """
         return sorted({key.code for key in self._store})
 
-    def record(self, error: "Violation") -> None:
+    def record(self, error: Violation) -> None:
         """Add the fact that the error was seen in the file.
 
         :param error:
             The Violation instance containing the information about the
             violation.
-        :type error:
-            flake8.style_guide.Violation
         """
         key = Key.create_from(error)
         if key not in self._store:
@@ -42,8 +35,8 @@ class Statistics:
         self._store[key].increment()
 
     def statistics_for(
-        self, prefix: str, filename: Optional[str] = None
-    ) -> Generator["Statistic", None, None]:
+        self, prefix: str, filename: str | None = None
+    ) -> Generator[Statistic, None, None]:
         """Generate statistics for the prefix and filename.
 
         If you have a :class:`Statistics` object that has recorded errors,
@@ -59,9 +52,9 @@ class Statistics:
             >>> stats.statistics_for('W')
             <generator ...>
 
-        :param str prefix:
+        :param prefix:
             The error class or specific error code to find statistics for.
-        :param str filename:
+        :param filename:
             (Optional) The filename to further filter results by.
         :returns:
             Generator of instances of :class:`Statistic`
@@ -73,7 +66,7 @@ class Statistics:
             yield self._store[error_code]
 
 
-class Key(collections.namedtuple("Key", ["filename", "code"])):
+class Key(NamedTuple):
     """Simple key structure for the Statistics dictionary.
 
     To make things clearer, easier to read, and more understandable, we use a
@@ -81,26 +74,25 @@ class Key(collections.namedtuple("Key", ["filename", "code"])):
     Statistics object.
     """
 
-    __slots__ = ()
+    filename: str
+    code: str
 
     @classmethod
-    def create_from(cls, error: "Violation") -> "Key":
-        """Create a Key from :class:`flake8.style_guide.Violation`."""
+    def create_from(cls, error: Violation) -> Key:
+        """Create a Key from :class:`flake8.violation.Violation`."""
         return cls(filename=error.filename, code=error.code)
 
-    def matches(self, prefix: str, filename: Optional[str]) -> bool:
+    def matches(self, prefix: str, filename: str | None) -> bool:
         """Determine if this key matches some constraints.
 
-        :param str prefix:
+        :param prefix:
             The error code prefix that this key's error code should start with.
-        :param str filename:
+        :param filename:
             The filename that we potentially want to match on. This can be
             None to only match on error prefix.
         :returns:
             True if the Key's code starts with the prefix and either filename
             is None, or the Key's filename matches the value passed in.
-        :rtype:
-            bool
         """
         return self.code.startswith(prefix) and (
             filename is None or self.filename == filename
@@ -111,7 +103,7 @@ class Statistic:
     """Simple wrapper around the logic of each statistic.
 
     Instead of maintaining a simple but potentially hard to reason about
-    tuple, we create a namedtuple which has attributes and a couple
+    tuple, we create a class which has attributes and a couple
     convenience methods on it.
     """
 
@@ -125,8 +117,8 @@ class Statistic:
         self.count = count
 
     @classmethod
-    def create_from(cls, error: "Violation") -> "Statistic":
-        """Create a Statistic from a :class:`flake8.style_guide.Violation`."""
+    def create_from(cls, error: Violation) -> Statistic:
+        """Create a Statistic from a :class:`flake8.violation.Violation`."""
         return cls(
             error_code=error.code,
             filename=error.filename,
